redvox.api1000.common API documentation

# Module `redvox.api1000.common`

## Sub-modules

`redvox.api1000.common.common`

  Provides common classes and methods for interacting with various API 1000 protobuf data.

`redvox.api1000.common.decorators`

  This module provides decorators used throughout the API M SDK codebase.

`redvox.api1000.common.generic`

  This module contains classes and function that make use of generics. As of April 2020, IntelliJ still does not parse generics correctly and cause …

`redvox.api1000.common.lz4`

  This module handles compression and decompression of API M data.

`redvox.api1000.common.mapping`

  This module provides functions and wrappers for working protobuf Map fields.

`redvox.api1000.common.metadata`

  This module provides functions and wrappers for working API M metadata fields.

`redvox.api1000.common.typing`

  This module contains routines for type checking and inspection.